from enum import Enum
import math
import string


class VolumeFlowUnits(Enum):
        """
            VolumeFlowUnits enumeration
        """
        
        CubicMeterPerSecond = 'cubic_meter_per_second'
        """
            
        """
        
        CubicMeterPerMinute = 'cubic_meter_per_minute'
        """
            
        """
        
        CubicMeterPerHour = 'cubic_meter_per_hour'
        """
            
        """
        
        CubicMeterPerDay = 'cubic_meter_per_day'
        """
            
        """
        
        CubicFootPerSecond = 'cubic_foot_per_second'
        """
            
        """
        
        CubicFootPerMinute = 'cubic_foot_per_minute'
        """
            
        """
        
        CubicFootPerHour = 'cubic_foot_per_hour'
        """
            
        """
        
        CubicYardPerSecond = 'cubic_yard_per_second'
        """
            
        """
        
        CubicYardPerMinute = 'cubic_yard_per_minute'
        """
            
        """
        
        CubicYardPerHour = 'cubic_yard_per_hour'
        """
            
        """
        
        CubicYardPerDay = 'cubic_yard_per_day'
        """
            
        """
        
        MillionUsGallonPerDay = 'million_us_gallon_per_day'
        """
            
        """
        
        UsGallonPerDay = 'us_gallon_per_day'
        """
            
        """
        
        LiterPerSecond = 'liter_per_second'
        """
            
        """
        
        LiterPerMinute = 'liter_per_minute'
        """
            
        """
        
        LiterPerHour = 'liter_per_hour'
        """
            
        """
        
        LiterPerDay = 'liter_per_day'
        """
            
        """
        
        UsGallonPerSecond = 'us_gallon_per_second'
        """
            
        """
        
        UsGallonPerMinute = 'us_gallon_per_minute'
        """
            
        """
        
        UkGallonPerDay = 'uk_gallon_per_day'
        """
            
        """
        
        UkGallonPerHour = 'uk_gallon_per_hour'
        """
            
        """
        
        UkGallonPerMinute = 'uk_gallon_per_minute'
        """
            
        """
        
        UkGallonPerSecond = 'uk_gallon_per_second'
        """
            
        """
        
        KilousGallonPerMinute = 'kilous_gallon_per_minute'
        """
            
        """
        
        UsGallonPerHour = 'us_gallon_per_hour'
        """
            
        """
        
        CubicDecimeterPerMinute = 'cubic_decimeter_per_minute'
        """
            
        """
        
        OilBarrelPerDay = 'oil_barrel_per_day'
        """
            
        """
        
        OilBarrelPerMinute = 'oil_barrel_per_minute'
        """
            
        """
        
        OilBarrelPerHour = 'oil_barrel_per_hour'
        """
            
        """
        
        OilBarrelPerSecond = 'oil_barrel_per_second'
        """
            
        """
        
        CubicMillimeterPerSecond = 'cubic_millimeter_per_second'
        """
            
        """
        
        AcreFootPerSecond = 'acre_foot_per_second'
        """
            
        """
        
        AcreFootPerMinute = 'acre_foot_per_minute'
        """
            
        """
        
        AcreFootPerHour = 'acre_foot_per_hour'
        """
            
        """
        
        AcreFootPerDay = 'acre_foot_per_day'
        """
            
        """
        
        CubicCentimeterPerMinute = 'cubic_centimeter_per_minute'
        """
            
        """
        
        MegausGallonPerDay = 'megaus_gallon_per_day'
        """
            
        """
        
        NanoliterPerSecond = 'nanoliter_per_second'
        """
            
        """
        
        MicroliterPerSecond = 'microliter_per_second'
        """
            
        """
        
        MilliliterPerSecond = 'milliliter_per_second'
        """
            
        """
        
        CentiliterPerSecond = 'centiliter_per_second'
        """
            
        """
        
        DeciliterPerSecond = 'deciliter_per_second'
        """
            
        """
        
        KiloliterPerSecond = 'kiloliter_per_second'
        """
            
        """
        
        MegaliterPerSecond = 'megaliter_per_second'
        """
            
        """
        
        NanoliterPerMinute = 'nanoliter_per_minute'
        """
            
        """
        
        MicroliterPerMinute = 'microliter_per_minute'
        """
            
        """
        
        MilliliterPerMinute = 'milliliter_per_minute'
        """
            
        """
        
        CentiliterPerMinute = 'centiliter_per_minute'
        """
            
        """
        
        DeciliterPerMinute = 'deciliter_per_minute'
        """
            
        """
        
        KiloliterPerMinute = 'kiloliter_per_minute'
        """
            
        """
        
        MegaliterPerMinute = 'megaliter_per_minute'
        """
            
        """
        
        NanoliterPerHour = 'nanoliter_per_hour'
        """
            
        """
        
        MicroliterPerHour = 'microliter_per_hour'
        """
            
        """
        
        MilliliterPerHour = 'milliliter_per_hour'
        """
            
        """
        
        CentiliterPerHour = 'centiliter_per_hour'
        """
            
        """
        
        DeciliterPerHour = 'deciliter_per_hour'
        """
            
        """
        
        KiloliterPerHour = 'kiloliter_per_hour'
        """
            
        """
        
        MegaliterPerHour = 'megaliter_per_hour'
        """
            
        """
        
        NanoliterPerDay = 'nanoliter_per_day'
        """
            
        """
        
        MicroliterPerDay = 'microliter_per_day'
        """
            
        """
        
        MilliliterPerDay = 'milliliter_per_day'
        """
            
        """
        
        CentiliterPerDay = 'centiliter_per_day'
        """
            
        """
        
        DeciliterPerDay = 'deciliter_per_day'
        """
            
        """
        
        KiloliterPerDay = 'kiloliter_per_day'
        """
            
        """
        
        MegaliterPerDay = 'megaliter_per_day'
        """
            
        """
        
        MegaukGallonPerDay = 'megauk_gallon_per_day'
        """
            
        """
        
        MegaukGallonPerSecond = 'megauk_gallon_per_second'
        """
            
        """
        

class VolumeFlow:
    """
    In physics and engineering, in particular fluid dynamics and hydrometry, the volumetric flow rate, (also known as volume flow rate, rate of fluid flow or volume velocity) is the volume of fluid which passes through a given surface per unit time. The SI unit is m³/s (cubic meters per second). In US Customary Units and British Imperial Units, volumetric flow rate is often expressed as ft³/s (cubic feet per second). It is usually represented by the symbol Q.

    Args:
        value (float): The value.
        from_unit (VolumeFlowUnits): The VolumeFlow unit to create from, The default unit is CubicMeterPerSecond
    """
    def __init__(self, value: float, from_unit: VolumeFlowUnits = VolumeFlowUnits.CubicMeterPerSecond):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__cubic_meters_per_second = None
        
        self.__cubic_meters_per_minute = None
        
        self.__cubic_meters_per_hour = None
        
        self.__cubic_meters_per_day = None
        
        self.__cubic_feet_per_second = None
        
        self.__cubic_feet_per_minute = None
        
        self.__cubic_feet_per_hour = None
        
        self.__cubic_yards_per_second = None
        
        self.__cubic_yards_per_minute = None
        
        self.__cubic_yards_per_hour = None
        
        self.__cubic_yards_per_day = None
        
        self.__million_us_gallons_per_day = None
        
        self.__us_gallons_per_day = None
        
        self.__liters_per_second = None
        
        self.__liters_per_minute = None
        
        self.__liters_per_hour = None
        
        self.__liters_per_day = None
        
        self.__us_gallons_per_second = None
        
        self.__us_gallons_per_minute = None
        
        self.__uk_gallons_per_day = None
        
        self.__uk_gallons_per_hour = None
        
        self.__uk_gallons_per_minute = None
        
        self.__uk_gallons_per_second = None
        
        self.__kilous_gallons_per_minute = None
        
        self.__us_gallons_per_hour = None
        
        self.__cubic_decimeters_per_minute = None
        
        self.__oil_barrels_per_day = None
        
        self.__oil_barrels_per_minute = None
        
        self.__oil_barrels_per_hour = None
        
        self.__oil_barrels_per_second = None
        
        self.__cubic_millimeters_per_second = None
        
        self.__acre_feet_per_second = None
        
        self.__acre_feet_per_minute = None
        
        self.__acre_feet_per_hour = None
        
        self.__acre_feet_per_day = None
        
        self.__cubic_centimeters_per_minute = None
        
        self.__megaus_gallons_per_day = None
        
        self.__nanoliters_per_second = None
        
        self.__microliters_per_second = None
        
        self.__milliliters_per_second = None
        
        self.__centiliters_per_second = None
        
        self.__deciliters_per_second = None
        
        self.__kiloliters_per_second = None
        
        self.__megaliters_per_second = None
        
        self.__nanoliters_per_minute = None
        
        self.__microliters_per_minute = None
        
        self.__milliliters_per_minute = None
        
        self.__centiliters_per_minute = None
        
        self.__deciliters_per_minute = None
        
        self.__kiloliters_per_minute = None
        
        self.__megaliters_per_minute = None
        
        self.__nanoliters_per_hour = None
        
        self.__microliters_per_hour = None
        
        self.__milliliters_per_hour = None
        
        self.__centiliters_per_hour = None
        
        self.__deciliters_per_hour = None
        
        self.__kiloliters_per_hour = None
        
        self.__megaliters_per_hour = None
        
        self.__nanoliters_per_day = None
        
        self.__microliters_per_day = None
        
        self.__milliliters_per_day = None
        
        self.__centiliters_per_day = None
        
        self.__deciliters_per_day = None
        
        self.__kiloliters_per_day = None
        
        self.__megaliters_per_day = None
        
        self.__megauk_gallons_per_day = None
        
        self.__megauk_gallons_per_second = None
        

    def __convert_from_base(self, from_unit: VolumeFlowUnits) -> float:
        value = self.__value
        
        if from_unit == VolumeFlowUnits.CubicMeterPerSecond:
            return (value)
        
        if from_unit == VolumeFlowUnits.CubicMeterPerMinute:
            return (value * 60)
        
        if from_unit == VolumeFlowUnits.CubicMeterPerHour:
            return (value * 3600)
        
        if from_unit == VolumeFlowUnits.CubicMeterPerDay:
            return (value * 86400)
        
        if from_unit == VolumeFlowUnits.CubicFootPerSecond:
            return (value * 35.314666721)
        
        if from_unit == VolumeFlowUnits.CubicFootPerMinute:
            return (value * 2118.88000326)
        
        if from_unit == VolumeFlowUnits.CubicFootPerHour:
            return (value / 7.8657907199999087346816086183876e-6)
        
        if from_unit == VolumeFlowUnits.CubicYardPerSecond:
            return (value / 0.764554857984)
        
        if from_unit == VolumeFlowUnits.CubicYardPerMinute:
            return (value / 0.0127425809664)
        
        if from_unit == VolumeFlowUnits.CubicYardPerHour:
            return (value / 2.1237634944e-4)
        
        if from_unit == VolumeFlowUnits.CubicYardPerDay:
            return (value * 113007)
        
        if from_unit == VolumeFlowUnits.MillionUsGallonPerDay:
            return (value * 22.824465227)
        
        if from_unit == VolumeFlowUnits.UsGallonPerDay:
            return (value * 22824465.227)
        
        if from_unit == VolumeFlowUnits.LiterPerSecond:
            return (value * 1000)
        
        if from_unit == VolumeFlowUnits.LiterPerMinute:
            return (value * 60000.00000)
        
        if from_unit == VolumeFlowUnits.LiterPerHour:
            return (value * 3600000.000)
        
        if from_unit == VolumeFlowUnits.LiterPerDay:
            return (value * 86400000)
        
        if from_unit == VolumeFlowUnits.UsGallonPerSecond:
            return (value * 264.1720523581484)
        
        if from_unit == VolumeFlowUnits.UsGallonPerMinute:
            return (value * 15850.323141489)
        
        if from_unit == VolumeFlowUnits.UkGallonPerDay:
            return (value * 19005304)
        
        if from_unit == VolumeFlowUnits.UkGallonPerHour:
            return (value * 791887.667)
        
        if from_unit == VolumeFlowUnits.UkGallonPerMinute:
            return (value * 13198.2)
        
        if from_unit == VolumeFlowUnits.UkGallonPerSecond:
            return (value * 219.969)
        
        if from_unit == VolumeFlowUnits.KilousGallonPerMinute:
            return (value * 15.850323141489)
        
        if from_unit == VolumeFlowUnits.UsGallonPerHour:
            return (value * 951019.38848933424)
        
        if from_unit == VolumeFlowUnits.CubicDecimeterPerMinute:
            return (value * 60000.00000)
        
        if from_unit == VolumeFlowUnits.OilBarrelPerDay:
            return (value / 1.8401307283333333333333333333333e-6)
        
        if from_unit == VolumeFlowUnits.OilBarrelPerMinute:
            return (value / 2.64978825e-3)
        
        if from_unit == VolumeFlowUnits.OilBarrelPerHour:
            return (value / 4.41631375e-5)
        
        if from_unit == VolumeFlowUnits.OilBarrelPerSecond:
            return (value * 6.28981)
        
        if from_unit == VolumeFlowUnits.CubicMillimeterPerSecond:
            return (value / 1e-9)
        
        if from_unit == VolumeFlowUnits.AcreFootPerSecond:
            return (value * 0.000810713194)
        
        if from_unit == VolumeFlowUnits.AcreFootPerMinute:
            return (value * 0.0486427916)
        
        if from_unit == VolumeFlowUnits.AcreFootPerHour:
            return (value * 2.91857)
        
        if from_unit == VolumeFlowUnits.AcreFootPerDay:
            return (value * 70.0457)
        
        if from_unit == VolumeFlowUnits.CubicCentimeterPerMinute:
            return (value / 1.6666666666667e-8)
        
        if from_unit == VolumeFlowUnits.MegausGallonPerDay:
            return ((value * 22824465.227) / 1000000.0)
        
        if from_unit == VolumeFlowUnits.NanoliterPerSecond:
            return ((value * 1000) / 1e-09)
        
        if from_unit == VolumeFlowUnits.MicroliterPerSecond:
            return ((value * 1000) / 1e-06)
        
        if from_unit == VolumeFlowUnits.MilliliterPerSecond:
            return ((value * 1000) / 0.001)
        
        if from_unit == VolumeFlowUnits.CentiliterPerSecond:
            return ((value * 1000) / 0.01)
        
        if from_unit == VolumeFlowUnits.DeciliterPerSecond:
            return ((value * 1000) / 0.1)
        
        if from_unit == VolumeFlowUnits.KiloliterPerSecond:
            return ((value * 1000) / 1000.0)
        
        if from_unit == VolumeFlowUnits.MegaliterPerSecond:
            return ((value * 1000) / 1000000.0)
        
        if from_unit == VolumeFlowUnits.NanoliterPerMinute:
            return ((value * 60000.00000) / 1e-09)
        
        if from_unit == VolumeFlowUnits.MicroliterPerMinute:
            return ((value * 60000.00000) / 1e-06)
        
        if from_unit == VolumeFlowUnits.MilliliterPerMinute:
            return ((value * 60000.00000) / 0.001)
        
        if from_unit == VolumeFlowUnits.CentiliterPerMinute:
            return ((value * 60000.00000) / 0.01)
        
        if from_unit == VolumeFlowUnits.DeciliterPerMinute:
            return ((value * 60000.00000) / 0.1)
        
        if from_unit == VolumeFlowUnits.KiloliterPerMinute:
            return ((value * 60000.00000) / 1000.0)
        
        if from_unit == VolumeFlowUnits.MegaliterPerMinute:
            return ((value * 60000.00000) / 1000000.0)
        
        if from_unit == VolumeFlowUnits.NanoliterPerHour:
            return ((value * 3600000.000) / 1e-09)
        
        if from_unit == VolumeFlowUnits.MicroliterPerHour:
            return ((value * 3600000.000) / 1e-06)
        
        if from_unit == VolumeFlowUnits.MilliliterPerHour:
            return ((value * 3600000.000) / 0.001)
        
        if from_unit == VolumeFlowUnits.CentiliterPerHour:
            return ((value * 3600000.000) / 0.01)
        
        if from_unit == VolumeFlowUnits.DeciliterPerHour:
            return ((value * 3600000.000) / 0.1)
        
        if from_unit == VolumeFlowUnits.KiloliterPerHour:
            return ((value * 3600000.000) / 1000.0)
        
        if from_unit == VolumeFlowUnits.MegaliterPerHour:
            return ((value * 3600000.000) / 1000000.0)
        
        if from_unit == VolumeFlowUnits.NanoliterPerDay:
            return ((value * 86400000) / 1e-09)
        
        if from_unit == VolumeFlowUnits.MicroliterPerDay:
            return ((value * 86400000) / 1e-06)
        
        if from_unit == VolumeFlowUnits.MilliliterPerDay:
            return ((value * 86400000) / 0.001)
        
        if from_unit == VolumeFlowUnits.CentiliterPerDay:
            return ((value * 86400000) / 0.01)
        
        if from_unit == VolumeFlowUnits.DeciliterPerDay:
            return ((value * 86400000) / 0.1)
        
        if from_unit == VolumeFlowUnits.KiloliterPerDay:
            return ((value * 86400000) / 1000.0)
        
        if from_unit == VolumeFlowUnits.MegaliterPerDay:
            return ((value * 86400000) / 1000000.0)
        
        if from_unit == VolumeFlowUnits.MegaukGallonPerDay:
            return ((value * 19005304) / 1000000.0)
        
        if from_unit == VolumeFlowUnits.MegaukGallonPerSecond:
            return ((value * 219.969) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: VolumeFlowUnits) -> float:
        
        if to_unit == VolumeFlowUnits.CubicMeterPerSecond:
            return (value)
        
        if to_unit == VolumeFlowUnits.CubicMeterPerMinute:
            return (value / 60)
        
        if to_unit == VolumeFlowUnits.CubicMeterPerHour:
            return (value / 3600)
        
        if to_unit == VolumeFlowUnits.CubicMeterPerDay:
            return (value / 86400)
        
        if to_unit == VolumeFlowUnits.CubicFootPerSecond:
            return (value / 35.314666721)
        
        if to_unit == VolumeFlowUnits.CubicFootPerMinute:
            return (value / 2118.88000326)
        
        if to_unit == VolumeFlowUnits.CubicFootPerHour:
            return (value * 7.8657907199999087346816086183876e-6)
        
        if to_unit == VolumeFlowUnits.CubicYardPerSecond:
            return (value * 0.764554857984)
        
        if to_unit == VolumeFlowUnits.CubicYardPerMinute:
            return (value * 0.0127425809664)
        
        if to_unit == VolumeFlowUnits.CubicYardPerHour:
            return (value * 2.1237634944e-4)
        
        if to_unit == VolumeFlowUnits.CubicYardPerDay:
            return (value / 113007)
        
        if to_unit == VolumeFlowUnits.MillionUsGallonPerDay:
            return (value / 22.824465227)
        
        if to_unit == VolumeFlowUnits.UsGallonPerDay:
            return (value / 22824465.227)
        
        if to_unit == VolumeFlowUnits.LiterPerSecond:
            return (value / 1000)
        
        if to_unit == VolumeFlowUnits.LiterPerMinute:
            return (value / 60000.00000)
        
        if to_unit == VolumeFlowUnits.LiterPerHour:
            return (value / 3600000.000)
        
        if to_unit == VolumeFlowUnits.LiterPerDay:
            return (value / 86400000)
        
        if to_unit == VolumeFlowUnits.UsGallonPerSecond:
            return (value / 264.1720523581484)
        
        if to_unit == VolumeFlowUnits.UsGallonPerMinute:
            return (value / 15850.323141489)
        
        if to_unit == VolumeFlowUnits.UkGallonPerDay:
            return (value / 19005304)
        
        if to_unit == VolumeFlowUnits.UkGallonPerHour:
            return (value / 791887.667)
        
        if to_unit == VolumeFlowUnits.UkGallonPerMinute:
            return (value / 13198.2)
        
        if to_unit == VolumeFlowUnits.UkGallonPerSecond:
            return (value / 219.969)
        
        if to_unit == VolumeFlowUnits.KilousGallonPerMinute:
            return (value / 15.850323141489)
        
        if to_unit == VolumeFlowUnits.UsGallonPerHour:
            return (value / 951019.38848933424)
        
        if to_unit == VolumeFlowUnits.CubicDecimeterPerMinute:
            return (value / 60000.00000)
        
        if to_unit == VolumeFlowUnits.OilBarrelPerDay:
            return (value * 1.8401307283333333333333333333333e-6)
        
        if to_unit == VolumeFlowUnits.OilBarrelPerMinute:
            return (value * 2.64978825e-3)
        
        if to_unit == VolumeFlowUnits.OilBarrelPerHour:
            return (value * 4.41631375e-5)
        
        if to_unit == VolumeFlowUnits.OilBarrelPerSecond:
            return (value / 6.28981)
        
        if to_unit == VolumeFlowUnits.CubicMillimeterPerSecond:
            return (value * 1e-9)
        
        if to_unit == VolumeFlowUnits.AcreFootPerSecond:
            return (value / 0.000810713194)
        
        if to_unit == VolumeFlowUnits.AcreFootPerMinute:
            return (value / 0.0486427916)
        
        if to_unit == VolumeFlowUnits.AcreFootPerHour:
            return (value / 2.91857)
        
        if to_unit == VolumeFlowUnits.AcreFootPerDay:
            return (value / 70.0457)
        
        if to_unit == VolumeFlowUnits.CubicCentimeterPerMinute:
            return (value * 1.6666666666667e-8)
        
        if to_unit == VolumeFlowUnits.MegausGallonPerDay:
            return ((value / 22824465.227) * 1000000.0)
        
        if to_unit == VolumeFlowUnits.NanoliterPerSecond:
            return ((value / 1000) * 1e-09)
        
        if to_unit == VolumeFlowUnits.MicroliterPerSecond:
            return ((value / 1000) * 1e-06)
        
        if to_unit == VolumeFlowUnits.MilliliterPerSecond:
            return ((value / 1000) * 0.001)
        
        if to_unit == VolumeFlowUnits.CentiliterPerSecond:
            return ((value / 1000) * 0.01)
        
        if to_unit == VolumeFlowUnits.DeciliterPerSecond:
            return ((value / 1000) * 0.1)
        
        if to_unit == VolumeFlowUnits.KiloliterPerSecond:
            return ((value / 1000) * 1000.0)
        
        if to_unit == VolumeFlowUnits.MegaliterPerSecond:
            return ((value / 1000) * 1000000.0)
        
        if to_unit == VolumeFlowUnits.NanoliterPerMinute:
            return ((value / 60000.00000) * 1e-09)
        
        if to_unit == VolumeFlowUnits.MicroliterPerMinute:
            return ((value / 60000.00000) * 1e-06)
        
        if to_unit == VolumeFlowUnits.MilliliterPerMinute:
            return ((value / 60000.00000) * 0.001)
        
        if to_unit == VolumeFlowUnits.CentiliterPerMinute:
            return ((value / 60000.00000) * 0.01)
        
        if to_unit == VolumeFlowUnits.DeciliterPerMinute:
            return ((value / 60000.00000) * 0.1)
        
        if to_unit == VolumeFlowUnits.KiloliterPerMinute:
            return ((value / 60000.00000) * 1000.0)
        
        if to_unit == VolumeFlowUnits.MegaliterPerMinute:
            return ((value / 60000.00000) * 1000000.0)
        
        if to_unit == VolumeFlowUnits.NanoliterPerHour:
            return ((value / 3600000.000) * 1e-09)
        
        if to_unit == VolumeFlowUnits.MicroliterPerHour:
            return ((value / 3600000.000) * 1e-06)
        
        if to_unit == VolumeFlowUnits.MilliliterPerHour:
            return ((value / 3600000.000) * 0.001)
        
        if to_unit == VolumeFlowUnits.CentiliterPerHour:
            return ((value / 3600000.000) * 0.01)
        
        if to_unit == VolumeFlowUnits.DeciliterPerHour:
            return ((value / 3600000.000) * 0.1)
        
        if to_unit == VolumeFlowUnits.KiloliterPerHour:
            return ((value / 3600000.000) * 1000.0)
        
        if to_unit == VolumeFlowUnits.MegaliterPerHour:
            return ((value / 3600000.000) * 1000000.0)
        
        if to_unit == VolumeFlowUnits.NanoliterPerDay:
            return ((value / 86400000) * 1e-09)
        
        if to_unit == VolumeFlowUnits.MicroliterPerDay:
            return ((value / 86400000) * 1e-06)
        
        if to_unit == VolumeFlowUnits.MilliliterPerDay:
            return ((value / 86400000) * 0.001)
        
        if to_unit == VolumeFlowUnits.CentiliterPerDay:
            return ((value / 86400000) * 0.01)
        
        if to_unit == VolumeFlowUnits.DeciliterPerDay:
            return ((value / 86400000) * 0.1)
        
        if to_unit == VolumeFlowUnits.KiloliterPerDay:
            return ((value / 86400000) * 1000.0)
        
        if to_unit == VolumeFlowUnits.MegaliterPerDay:
            return ((value / 86400000) * 1000000.0)
        
        if to_unit == VolumeFlowUnits.MegaukGallonPerDay:
            return ((value / 19005304) * 1000000.0)
        
        if to_unit == VolumeFlowUnits.MegaukGallonPerSecond:
            return ((value / 219.969) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_cubic_meters_per_second(cubic_meters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_meters_per_second.

        

        :param meters: The VolumeFlow value in cubic_meters_per_second.
        :type cubic_meters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_meters_per_second, VolumeFlowUnits.CubicMeterPerSecond)

    
    @staticmethod
    def from_cubic_meters_per_minute(cubic_meters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_meters_per_minute.

        

        :param meters: The VolumeFlow value in cubic_meters_per_minute.
        :type cubic_meters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_meters_per_minute, VolumeFlowUnits.CubicMeterPerMinute)

    
    @staticmethod
    def from_cubic_meters_per_hour(cubic_meters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_meters_per_hour.

        

        :param meters: The VolumeFlow value in cubic_meters_per_hour.
        :type cubic_meters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_meters_per_hour, VolumeFlowUnits.CubicMeterPerHour)

    
    @staticmethod
    def from_cubic_meters_per_day(cubic_meters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_meters_per_day.

        

        :param meters: The VolumeFlow value in cubic_meters_per_day.
        :type cubic_meters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_meters_per_day, VolumeFlowUnits.CubicMeterPerDay)

    
    @staticmethod
    def from_cubic_feet_per_second(cubic_feet_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_feet_per_second.

        

        :param meters: The VolumeFlow value in cubic_feet_per_second.
        :type cubic_feet_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_feet_per_second, VolumeFlowUnits.CubicFootPerSecond)

    
    @staticmethod
    def from_cubic_feet_per_minute(cubic_feet_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_feet_per_minute.

        

        :param meters: The VolumeFlow value in cubic_feet_per_minute.
        :type cubic_feet_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_feet_per_minute, VolumeFlowUnits.CubicFootPerMinute)

    
    @staticmethod
    def from_cubic_feet_per_hour(cubic_feet_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_feet_per_hour.

        

        :param meters: The VolumeFlow value in cubic_feet_per_hour.
        :type cubic_feet_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_feet_per_hour, VolumeFlowUnits.CubicFootPerHour)

    
    @staticmethod
    def from_cubic_yards_per_second(cubic_yards_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_yards_per_second.

        

        :param meters: The VolumeFlow value in cubic_yards_per_second.
        :type cubic_yards_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_yards_per_second, VolumeFlowUnits.CubicYardPerSecond)

    
    @staticmethod
    def from_cubic_yards_per_minute(cubic_yards_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_yards_per_minute.

        

        :param meters: The VolumeFlow value in cubic_yards_per_minute.
        :type cubic_yards_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_yards_per_minute, VolumeFlowUnits.CubicYardPerMinute)

    
    @staticmethod
    def from_cubic_yards_per_hour(cubic_yards_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_yards_per_hour.

        

        :param meters: The VolumeFlow value in cubic_yards_per_hour.
        :type cubic_yards_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_yards_per_hour, VolumeFlowUnits.CubicYardPerHour)

    
    @staticmethod
    def from_cubic_yards_per_day(cubic_yards_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_yards_per_day.

        

        :param meters: The VolumeFlow value in cubic_yards_per_day.
        :type cubic_yards_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_yards_per_day, VolumeFlowUnits.CubicYardPerDay)

    
    @staticmethod
    def from_million_us_gallons_per_day(million_us_gallons_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in million_us_gallons_per_day.

        

        :param meters: The VolumeFlow value in million_us_gallons_per_day.
        :type million_us_gallons_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(million_us_gallons_per_day, VolumeFlowUnits.MillionUsGallonPerDay)

    
    @staticmethod
    def from_us_gallons_per_day(us_gallons_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in us_gallons_per_day.

        

        :param meters: The VolumeFlow value in us_gallons_per_day.
        :type us_gallons_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(us_gallons_per_day, VolumeFlowUnits.UsGallonPerDay)

    
    @staticmethod
    def from_liters_per_second(liters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in liters_per_second.

        

        :param meters: The VolumeFlow value in liters_per_second.
        :type liters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(liters_per_second, VolumeFlowUnits.LiterPerSecond)

    
    @staticmethod
    def from_liters_per_minute(liters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in liters_per_minute.

        

        :param meters: The VolumeFlow value in liters_per_minute.
        :type liters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(liters_per_minute, VolumeFlowUnits.LiterPerMinute)

    
    @staticmethod
    def from_liters_per_hour(liters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in liters_per_hour.

        

        :param meters: The VolumeFlow value in liters_per_hour.
        :type liters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(liters_per_hour, VolumeFlowUnits.LiterPerHour)

    
    @staticmethod
    def from_liters_per_day(liters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in liters_per_day.

        

        :param meters: The VolumeFlow value in liters_per_day.
        :type liters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(liters_per_day, VolumeFlowUnits.LiterPerDay)

    
    @staticmethod
    def from_us_gallons_per_second(us_gallons_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in us_gallons_per_second.

        

        :param meters: The VolumeFlow value in us_gallons_per_second.
        :type us_gallons_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(us_gallons_per_second, VolumeFlowUnits.UsGallonPerSecond)

    
    @staticmethod
    def from_us_gallons_per_minute(us_gallons_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in us_gallons_per_minute.

        

        :param meters: The VolumeFlow value in us_gallons_per_minute.
        :type us_gallons_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(us_gallons_per_minute, VolumeFlowUnits.UsGallonPerMinute)

    
    @staticmethod
    def from_uk_gallons_per_day(uk_gallons_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in uk_gallons_per_day.

        

        :param meters: The VolumeFlow value in uk_gallons_per_day.
        :type uk_gallons_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(uk_gallons_per_day, VolumeFlowUnits.UkGallonPerDay)

    
    @staticmethod
    def from_uk_gallons_per_hour(uk_gallons_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in uk_gallons_per_hour.

        

        :param meters: The VolumeFlow value in uk_gallons_per_hour.
        :type uk_gallons_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(uk_gallons_per_hour, VolumeFlowUnits.UkGallonPerHour)

    
    @staticmethod
    def from_uk_gallons_per_minute(uk_gallons_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in uk_gallons_per_minute.

        

        :param meters: The VolumeFlow value in uk_gallons_per_minute.
        :type uk_gallons_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(uk_gallons_per_minute, VolumeFlowUnits.UkGallonPerMinute)

    
    @staticmethod
    def from_uk_gallons_per_second(uk_gallons_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in uk_gallons_per_second.

        

        :param meters: The VolumeFlow value in uk_gallons_per_second.
        :type uk_gallons_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(uk_gallons_per_second, VolumeFlowUnits.UkGallonPerSecond)

    
    @staticmethod
    def from_kilous_gallons_per_minute(kilous_gallons_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in kilous_gallons_per_minute.

        

        :param meters: The VolumeFlow value in kilous_gallons_per_minute.
        :type kilous_gallons_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(kilous_gallons_per_minute, VolumeFlowUnits.KilousGallonPerMinute)

    
    @staticmethod
    def from_us_gallons_per_hour(us_gallons_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in us_gallons_per_hour.

        

        :param meters: The VolumeFlow value in us_gallons_per_hour.
        :type us_gallons_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(us_gallons_per_hour, VolumeFlowUnits.UsGallonPerHour)

    
    @staticmethod
    def from_cubic_decimeters_per_minute(cubic_decimeters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_decimeters_per_minute.

        

        :param meters: The VolumeFlow value in cubic_decimeters_per_minute.
        :type cubic_decimeters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_decimeters_per_minute, VolumeFlowUnits.CubicDecimeterPerMinute)

    
    @staticmethod
    def from_oil_barrels_per_day(oil_barrels_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in oil_barrels_per_day.

        

        :param meters: The VolumeFlow value in oil_barrels_per_day.
        :type oil_barrels_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(oil_barrels_per_day, VolumeFlowUnits.OilBarrelPerDay)

    
    @staticmethod
    def from_oil_barrels_per_minute(oil_barrels_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in oil_barrels_per_minute.

        

        :param meters: The VolumeFlow value in oil_barrels_per_minute.
        :type oil_barrels_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(oil_barrels_per_minute, VolumeFlowUnits.OilBarrelPerMinute)

    
    @staticmethod
    def from_oil_barrels_per_hour(oil_barrels_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in oil_barrels_per_hour.

        

        :param meters: The VolumeFlow value in oil_barrels_per_hour.
        :type oil_barrels_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(oil_barrels_per_hour, VolumeFlowUnits.OilBarrelPerHour)

    
    @staticmethod
    def from_oil_barrels_per_second(oil_barrels_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in oil_barrels_per_second.

        

        :param meters: The VolumeFlow value in oil_barrels_per_second.
        :type oil_barrels_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(oil_barrels_per_second, VolumeFlowUnits.OilBarrelPerSecond)

    
    @staticmethod
    def from_cubic_millimeters_per_second(cubic_millimeters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_millimeters_per_second.

        

        :param meters: The VolumeFlow value in cubic_millimeters_per_second.
        :type cubic_millimeters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_millimeters_per_second, VolumeFlowUnits.CubicMillimeterPerSecond)

    
    @staticmethod
    def from_acre_feet_per_second(acre_feet_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in acre_feet_per_second.

        

        :param meters: The VolumeFlow value in acre_feet_per_second.
        :type acre_feet_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(acre_feet_per_second, VolumeFlowUnits.AcreFootPerSecond)

    
    @staticmethod
    def from_acre_feet_per_minute(acre_feet_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in acre_feet_per_minute.

        

        :param meters: The VolumeFlow value in acre_feet_per_minute.
        :type acre_feet_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(acre_feet_per_minute, VolumeFlowUnits.AcreFootPerMinute)

    
    @staticmethod
    def from_acre_feet_per_hour(acre_feet_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in acre_feet_per_hour.

        

        :param meters: The VolumeFlow value in acre_feet_per_hour.
        :type acre_feet_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(acre_feet_per_hour, VolumeFlowUnits.AcreFootPerHour)

    
    @staticmethod
    def from_acre_feet_per_day(acre_feet_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in acre_feet_per_day.

        

        :param meters: The VolumeFlow value in acre_feet_per_day.
        :type acre_feet_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(acre_feet_per_day, VolumeFlowUnits.AcreFootPerDay)

    
    @staticmethod
    def from_cubic_centimeters_per_minute(cubic_centimeters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in cubic_centimeters_per_minute.

        

        :param meters: The VolumeFlow value in cubic_centimeters_per_minute.
        :type cubic_centimeters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(cubic_centimeters_per_minute, VolumeFlowUnits.CubicCentimeterPerMinute)

    
    @staticmethod
    def from_megaus_gallons_per_day(megaus_gallons_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in megaus_gallons_per_day.

        

        :param meters: The VolumeFlow value in megaus_gallons_per_day.
        :type megaus_gallons_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megaus_gallons_per_day, VolumeFlowUnits.MegausGallonPerDay)

    
    @staticmethod
    def from_nanoliters_per_second(nanoliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in nanoliters_per_second.

        

        :param meters: The VolumeFlow value in nanoliters_per_second.
        :type nanoliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(nanoliters_per_second, VolumeFlowUnits.NanoliterPerSecond)

    
    @staticmethod
    def from_microliters_per_second(microliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in microliters_per_second.

        

        :param meters: The VolumeFlow value in microliters_per_second.
        :type microliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(microliters_per_second, VolumeFlowUnits.MicroliterPerSecond)

    
    @staticmethod
    def from_milliliters_per_second(milliliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in milliliters_per_second.

        

        :param meters: The VolumeFlow value in milliliters_per_second.
        :type milliliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(milliliters_per_second, VolumeFlowUnits.MilliliterPerSecond)

    
    @staticmethod
    def from_centiliters_per_second(centiliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in centiliters_per_second.

        

        :param meters: The VolumeFlow value in centiliters_per_second.
        :type centiliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(centiliters_per_second, VolumeFlowUnits.CentiliterPerSecond)

    
    @staticmethod
    def from_deciliters_per_second(deciliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in deciliters_per_second.

        

        :param meters: The VolumeFlow value in deciliters_per_second.
        :type deciliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(deciliters_per_second, VolumeFlowUnits.DeciliterPerSecond)

    
    @staticmethod
    def from_kiloliters_per_second(kiloliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in kiloliters_per_second.

        

        :param meters: The VolumeFlow value in kiloliters_per_second.
        :type kiloliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(kiloliters_per_second, VolumeFlowUnits.KiloliterPerSecond)

    
    @staticmethod
    def from_megaliters_per_second(megaliters_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in megaliters_per_second.

        

        :param meters: The VolumeFlow value in megaliters_per_second.
        :type megaliters_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megaliters_per_second, VolumeFlowUnits.MegaliterPerSecond)

    
    @staticmethod
    def from_nanoliters_per_minute(nanoliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in nanoliters_per_minute.

        

        :param meters: The VolumeFlow value in nanoliters_per_minute.
        :type nanoliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(nanoliters_per_minute, VolumeFlowUnits.NanoliterPerMinute)

    
    @staticmethod
    def from_microliters_per_minute(microliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in microliters_per_minute.

        

        :param meters: The VolumeFlow value in microliters_per_minute.
        :type microliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(microliters_per_minute, VolumeFlowUnits.MicroliterPerMinute)

    
    @staticmethod
    def from_milliliters_per_minute(milliliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in milliliters_per_minute.

        

        :param meters: The VolumeFlow value in milliliters_per_minute.
        :type milliliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(milliliters_per_minute, VolumeFlowUnits.MilliliterPerMinute)

    
    @staticmethod
    def from_centiliters_per_minute(centiliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in centiliters_per_minute.

        

        :param meters: The VolumeFlow value in centiliters_per_minute.
        :type centiliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(centiliters_per_minute, VolumeFlowUnits.CentiliterPerMinute)

    
    @staticmethod
    def from_deciliters_per_minute(deciliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in deciliters_per_minute.

        

        :param meters: The VolumeFlow value in deciliters_per_minute.
        :type deciliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(deciliters_per_minute, VolumeFlowUnits.DeciliterPerMinute)

    
    @staticmethod
    def from_kiloliters_per_minute(kiloliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in kiloliters_per_minute.

        

        :param meters: The VolumeFlow value in kiloliters_per_minute.
        :type kiloliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(kiloliters_per_minute, VolumeFlowUnits.KiloliterPerMinute)

    
    @staticmethod
    def from_megaliters_per_minute(megaliters_per_minute: float):
        """
        Create a new instance of VolumeFlow from a value in megaliters_per_minute.

        

        :param meters: The VolumeFlow value in megaliters_per_minute.
        :type megaliters_per_minute: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megaliters_per_minute, VolumeFlowUnits.MegaliterPerMinute)

    
    @staticmethod
    def from_nanoliters_per_hour(nanoliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in nanoliters_per_hour.

        

        :param meters: The VolumeFlow value in nanoliters_per_hour.
        :type nanoliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(nanoliters_per_hour, VolumeFlowUnits.NanoliterPerHour)

    
    @staticmethod
    def from_microliters_per_hour(microliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in microliters_per_hour.

        

        :param meters: The VolumeFlow value in microliters_per_hour.
        :type microliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(microliters_per_hour, VolumeFlowUnits.MicroliterPerHour)

    
    @staticmethod
    def from_milliliters_per_hour(milliliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in milliliters_per_hour.

        

        :param meters: The VolumeFlow value in milliliters_per_hour.
        :type milliliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(milliliters_per_hour, VolumeFlowUnits.MilliliterPerHour)

    
    @staticmethod
    def from_centiliters_per_hour(centiliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in centiliters_per_hour.

        

        :param meters: The VolumeFlow value in centiliters_per_hour.
        :type centiliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(centiliters_per_hour, VolumeFlowUnits.CentiliterPerHour)

    
    @staticmethod
    def from_deciliters_per_hour(deciliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in deciliters_per_hour.

        

        :param meters: The VolumeFlow value in deciliters_per_hour.
        :type deciliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(deciliters_per_hour, VolumeFlowUnits.DeciliterPerHour)

    
    @staticmethod
    def from_kiloliters_per_hour(kiloliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in kiloliters_per_hour.

        

        :param meters: The VolumeFlow value in kiloliters_per_hour.
        :type kiloliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(kiloliters_per_hour, VolumeFlowUnits.KiloliterPerHour)

    
    @staticmethod
    def from_megaliters_per_hour(megaliters_per_hour: float):
        """
        Create a new instance of VolumeFlow from a value in megaliters_per_hour.

        

        :param meters: The VolumeFlow value in megaliters_per_hour.
        :type megaliters_per_hour: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megaliters_per_hour, VolumeFlowUnits.MegaliterPerHour)

    
    @staticmethod
    def from_nanoliters_per_day(nanoliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in nanoliters_per_day.

        

        :param meters: The VolumeFlow value in nanoliters_per_day.
        :type nanoliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(nanoliters_per_day, VolumeFlowUnits.NanoliterPerDay)

    
    @staticmethod
    def from_microliters_per_day(microliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in microliters_per_day.

        

        :param meters: The VolumeFlow value in microliters_per_day.
        :type microliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(microliters_per_day, VolumeFlowUnits.MicroliterPerDay)

    
    @staticmethod
    def from_milliliters_per_day(milliliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in milliliters_per_day.

        

        :param meters: The VolumeFlow value in milliliters_per_day.
        :type milliliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(milliliters_per_day, VolumeFlowUnits.MilliliterPerDay)

    
    @staticmethod
    def from_centiliters_per_day(centiliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in centiliters_per_day.

        

        :param meters: The VolumeFlow value in centiliters_per_day.
        :type centiliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(centiliters_per_day, VolumeFlowUnits.CentiliterPerDay)

    
    @staticmethod
    def from_deciliters_per_day(deciliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in deciliters_per_day.

        

        :param meters: The VolumeFlow value in deciliters_per_day.
        :type deciliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(deciliters_per_day, VolumeFlowUnits.DeciliterPerDay)

    
    @staticmethod
    def from_kiloliters_per_day(kiloliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in kiloliters_per_day.

        

        :param meters: The VolumeFlow value in kiloliters_per_day.
        :type kiloliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(kiloliters_per_day, VolumeFlowUnits.KiloliterPerDay)

    
    @staticmethod
    def from_megaliters_per_day(megaliters_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in megaliters_per_day.

        

        :param meters: The VolumeFlow value in megaliters_per_day.
        :type megaliters_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megaliters_per_day, VolumeFlowUnits.MegaliterPerDay)

    
    @staticmethod
    def from_megauk_gallons_per_day(megauk_gallons_per_day: float):
        """
        Create a new instance of VolumeFlow from a value in megauk_gallons_per_day.

        

        :param meters: The VolumeFlow value in megauk_gallons_per_day.
        :type megauk_gallons_per_day: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megauk_gallons_per_day, VolumeFlowUnits.MegaukGallonPerDay)

    
    @staticmethod
    def from_megauk_gallons_per_second(megauk_gallons_per_second: float):
        """
        Create a new instance of VolumeFlow from a value in megauk_gallons_per_second.

        

        :param meters: The VolumeFlow value in megauk_gallons_per_second.
        :type megauk_gallons_per_second: float
        :return: A new instance of VolumeFlow.
        :rtype: VolumeFlow
        """
        return VolumeFlow(megauk_gallons_per_second, VolumeFlowUnits.MegaukGallonPerSecond)

    
    @property
    def cubic_meters_per_second(self) -> float:
        """
        
        """
        if self.__cubic_meters_per_second != None:
            return self.__cubic_meters_per_second
        self.__cubic_meters_per_second = self.__convert_from_base(VolumeFlowUnits.CubicMeterPerSecond)
        return self.__cubic_meters_per_second

    
    @property
    def cubic_meters_per_minute(self) -> float:
        """
        
        """
        if self.__cubic_meters_per_minute != None:
            return self.__cubic_meters_per_minute
        self.__cubic_meters_per_minute = self.__convert_from_base(VolumeFlowUnits.CubicMeterPerMinute)
        return self.__cubic_meters_per_minute

    
    @property
    def cubic_meters_per_hour(self) -> float:
        """
        
        """
        if self.__cubic_meters_per_hour != None:
            return self.__cubic_meters_per_hour
        self.__cubic_meters_per_hour = self.__convert_from_base(VolumeFlowUnits.CubicMeterPerHour)
        return self.__cubic_meters_per_hour

    
    @property
    def cubic_meters_per_day(self) -> float:
        """
        
        """
        if self.__cubic_meters_per_day != None:
            return self.__cubic_meters_per_day
        self.__cubic_meters_per_day = self.__convert_from_base(VolumeFlowUnits.CubicMeterPerDay)
        return self.__cubic_meters_per_day

    
    @property
    def cubic_feet_per_second(self) -> float:
        """
        
        """
        if self.__cubic_feet_per_second != None:
            return self.__cubic_feet_per_second
        self.__cubic_feet_per_second = self.__convert_from_base(VolumeFlowUnits.CubicFootPerSecond)
        return self.__cubic_feet_per_second

    
    @property
    def cubic_feet_per_minute(self) -> float:
        """
        
        """
        if self.__cubic_feet_per_minute != None:
            return self.__cubic_feet_per_minute
        self.__cubic_feet_per_minute = self.__convert_from_base(VolumeFlowUnits.CubicFootPerMinute)
        return self.__cubic_feet_per_minute

    
    @property
    def cubic_feet_per_hour(self) -> float:
        """
        
        """
        if self.__cubic_feet_per_hour != None:
            return self.__cubic_feet_per_hour
        self.__cubic_feet_per_hour = self.__convert_from_base(VolumeFlowUnits.CubicFootPerHour)
        return self.__cubic_feet_per_hour

    
    @property
    def cubic_yards_per_second(self) -> float:
        """
        
        """
        if self.__cubic_yards_per_second != None:
            return self.__cubic_yards_per_second
        self.__cubic_yards_per_second = self.__convert_from_base(VolumeFlowUnits.CubicYardPerSecond)
        return self.__cubic_yards_per_second

    
    @property
    def cubic_yards_per_minute(self) -> float:
        """
        
        """
        if self.__cubic_yards_per_minute != None:
            return self.__cubic_yards_per_minute
        self.__cubic_yards_per_minute = self.__convert_from_base(VolumeFlowUnits.CubicYardPerMinute)
        return self.__cubic_yards_per_minute

    
    @property
    def cubic_yards_per_hour(self) -> float:
        """
        
        """
        if self.__cubic_yards_per_hour != None:
            return self.__cubic_yards_per_hour
        self.__cubic_yards_per_hour = self.__convert_from_base(VolumeFlowUnits.CubicYardPerHour)
        return self.__cubic_yards_per_hour

    
    @property
    def cubic_yards_per_day(self) -> float:
        """
        
        """
        if self.__cubic_yards_per_day != None:
            return self.__cubic_yards_per_day
        self.__cubic_yards_per_day = self.__convert_from_base(VolumeFlowUnits.CubicYardPerDay)
        return self.__cubic_yards_per_day

    
    @property
    def million_us_gallons_per_day(self) -> float:
        """
        
        """
        if self.__million_us_gallons_per_day != None:
            return self.__million_us_gallons_per_day
        self.__million_us_gallons_per_day = self.__convert_from_base(VolumeFlowUnits.MillionUsGallonPerDay)
        return self.__million_us_gallons_per_day

    
    @property
    def us_gallons_per_day(self) -> float:
        """
        
        """
        if self.__us_gallons_per_day != None:
            return self.__us_gallons_per_day
        self.__us_gallons_per_day = self.__convert_from_base(VolumeFlowUnits.UsGallonPerDay)
        return self.__us_gallons_per_day

    
    @property
    def liters_per_second(self) -> float:
        """
        
        """
        if self.__liters_per_second != None:
            return self.__liters_per_second
        self.__liters_per_second = self.__convert_from_base(VolumeFlowUnits.LiterPerSecond)
        return self.__liters_per_second

    
    @property
    def liters_per_minute(self) -> float:
        """
        
        """
        if self.__liters_per_minute != None:
            return self.__liters_per_minute
        self.__liters_per_minute = self.__convert_from_base(VolumeFlowUnits.LiterPerMinute)
        return self.__liters_per_minute

    
    @property
    def liters_per_hour(self) -> float:
        """
        
        """
        if self.__liters_per_hour != None:
            return self.__liters_per_hour
        self.__liters_per_hour = self.__convert_from_base(VolumeFlowUnits.LiterPerHour)
        return self.__liters_per_hour

    
    @property
    def liters_per_day(self) -> float:
        """
        
        """
        if self.__liters_per_day != None:
            return self.__liters_per_day
        self.__liters_per_day = self.__convert_from_base(VolumeFlowUnits.LiterPerDay)
        return self.__liters_per_day

    
    @property
    def us_gallons_per_second(self) -> float:
        """
        
        """
        if self.__us_gallons_per_second != None:
            return self.__us_gallons_per_second
        self.__us_gallons_per_second = self.__convert_from_base(VolumeFlowUnits.UsGallonPerSecond)
        return self.__us_gallons_per_second

    
    @property
    def us_gallons_per_minute(self) -> float:
        """
        
        """
        if self.__us_gallons_per_minute != None:
            return self.__us_gallons_per_minute
        self.__us_gallons_per_minute = self.__convert_from_base(VolumeFlowUnits.UsGallonPerMinute)
        return self.__us_gallons_per_minute

    
    @property
    def uk_gallons_per_day(self) -> float:
        """
        
        """
        if self.__uk_gallons_per_day != None:
            return self.__uk_gallons_per_day
        self.__uk_gallons_per_day = self.__convert_from_base(VolumeFlowUnits.UkGallonPerDay)
        return self.__uk_gallons_per_day

    
    @property
    def uk_gallons_per_hour(self) -> float:
        """
        
        """
        if self.__uk_gallons_per_hour != None:
            return self.__uk_gallons_per_hour
        self.__uk_gallons_per_hour = self.__convert_from_base(VolumeFlowUnits.UkGallonPerHour)
        return self.__uk_gallons_per_hour

    
    @property
    def uk_gallons_per_minute(self) -> float:
        """
        
        """
        if self.__uk_gallons_per_minute != None:
            return self.__uk_gallons_per_minute
        self.__uk_gallons_per_minute = self.__convert_from_base(VolumeFlowUnits.UkGallonPerMinute)
        return self.__uk_gallons_per_minute

    
    @property
    def uk_gallons_per_second(self) -> float:
        """
        
        """
        if self.__uk_gallons_per_second != None:
            return self.__uk_gallons_per_second
        self.__uk_gallons_per_second = self.__convert_from_base(VolumeFlowUnits.UkGallonPerSecond)
        return self.__uk_gallons_per_second

    
    @property
    def kilous_gallons_per_minute(self) -> float:
        """
        
        """
        if self.__kilous_gallons_per_minute != None:
            return self.__kilous_gallons_per_minute
        self.__kilous_gallons_per_minute = self.__convert_from_base(VolumeFlowUnits.KilousGallonPerMinute)
        return self.__kilous_gallons_per_minute

    
    @property
    def us_gallons_per_hour(self) -> float:
        """
        
        """
        if self.__us_gallons_per_hour != None:
            return self.__us_gallons_per_hour
        self.__us_gallons_per_hour = self.__convert_from_base(VolumeFlowUnits.UsGallonPerHour)
        return self.__us_gallons_per_hour

    
    @property
    def cubic_decimeters_per_minute(self) -> float:
        """
        
        """
        if self.__cubic_decimeters_per_minute != None:
            return self.__cubic_decimeters_per_minute
        self.__cubic_decimeters_per_minute = self.__convert_from_base(VolumeFlowUnits.CubicDecimeterPerMinute)
        return self.__cubic_decimeters_per_minute

    
    @property
    def oil_barrels_per_day(self) -> float:
        """
        
        """
        if self.__oil_barrels_per_day != None:
            return self.__oil_barrels_per_day
        self.__oil_barrels_per_day = self.__convert_from_base(VolumeFlowUnits.OilBarrelPerDay)
        return self.__oil_barrels_per_day

    
    @property
    def oil_barrels_per_minute(self) -> float:
        """
        
        """
        if self.__oil_barrels_per_minute != None:
            return self.__oil_barrels_per_minute
        self.__oil_barrels_per_minute = self.__convert_from_base(VolumeFlowUnits.OilBarrelPerMinute)
        return self.__oil_barrels_per_minute

    
    @property
    def oil_barrels_per_hour(self) -> float:
        """
        
        """
        if self.__oil_barrels_per_hour != None:
            return self.__oil_barrels_per_hour
        self.__oil_barrels_per_hour = self.__convert_from_base(VolumeFlowUnits.OilBarrelPerHour)
        return self.__oil_barrels_per_hour

    
    @property
    def oil_barrels_per_second(self) -> float:
        """
        
        """
        if self.__oil_barrels_per_second != None:
            return self.__oil_barrels_per_second
        self.__oil_barrels_per_second = self.__convert_from_base(VolumeFlowUnits.OilBarrelPerSecond)
        return self.__oil_barrels_per_second

    
    @property
    def cubic_millimeters_per_second(self) -> float:
        """
        
        """
        if self.__cubic_millimeters_per_second != None:
            return self.__cubic_millimeters_per_second
        self.__cubic_millimeters_per_second = self.__convert_from_base(VolumeFlowUnits.CubicMillimeterPerSecond)
        return self.__cubic_millimeters_per_second

    
    @property
    def acre_feet_per_second(self) -> float:
        """
        
        """
        if self.__acre_feet_per_second != None:
            return self.__acre_feet_per_second
        self.__acre_feet_per_second = self.__convert_from_base(VolumeFlowUnits.AcreFootPerSecond)
        return self.__acre_feet_per_second

    
    @property
    def acre_feet_per_minute(self) -> float:
        """
        
        """
        if self.__acre_feet_per_minute != None:
            return self.__acre_feet_per_minute
        self.__acre_feet_per_minute = self.__convert_from_base(VolumeFlowUnits.AcreFootPerMinute)
        return self.__acre_feet_per_minute

    
    @property
    def acre_feet_per_hour(self) -> float:
        """
        
        """
        if self.__acre_feet_per_hour != None:
            return self.__acre_feet_per_hour
        self.__acre_feet_per_hour = self.__convert_from_base(VolumeFlowUnits.AcreFootPerHour)
        return self.__acre_feet_per_hour

    
    @property
    def acre_feet_per_day(self) -> float:
        """
        
        """
        if self.__acre_feet_per_day != None:
            return self.__acre_feet_per_day
        self.__acre_feet_per_day = self.__convert_from_base(VolumeFlowUnits.AcreFootPerDay)
        return self.__acre_feet_per_day

    
    @property
    def cubic_centimeters_per_minute(self) -> float:
        """
        
        """
        if self.__cubic_centimeters_per_minute != None:
            return self.__cubic_centimeters_per_minute
        self.__cubic_centimeters_per_minute = self.__convert_from_base(VolumeFlowUnits.CubicCentimeterPerMinute)
        return self.__cubic_centimeters_per_minute

    
    @property
    def megaus_gallons_per_day(self) -> float:
        """
        
        """
        if self.__megaus_gallons_per_day != None:
            return self.__megaus_gallons_per_day
        self.__megaus_gallons_per_day = self.__convert_from_base(VolumeFlowUnits.MegausGallonPerDay)
        return self.__megaus_gallons_per_day

    
    @property
    def nanoliters_per_second(self) -> float:
        """
        
        """
        if self.__nanoliters_per_second != None:
            return self.__nanoliters_per_second
        self.__nanoliters_per_second = self.__convert_from_base(VolumeFlowUnits.NanoliterPerSecond)
        return self.__nanoliters_per_second

    
    @property
    def microliters_per_second(self) -> float:
        """
        
        """
        if self.__microliters_per_second != None:
            return self.__microliters_per_second
        self.__microliters_per_second = self.__convert_from_base(VolumeFlowUnits.MicroliterPerSecond)
        return self.__microliters_per_second

    
    @property
    def milliliters_per_second(self) -> float:
        """
        
        """
        if self.__milliliters_per_second != None:
            return self.__milliliters_per_second
        self.__milliliters_per_second = self.__convert_from_base(VolumeFlowUnits.MilliliterPerSecond)
        return self.__milliliters_per_second

    
    @property
    def centiliters_per_second(self) -> float:
        """
        
        """
        if self.__centiliters_per_second != None:
            return self.__centiliters_per_second
        self.__centiliters_per_second = self.__convert_from_base(VolumeFlowUnits.CentiliterPerSecond)
        return self.__centiliters_per_second

    
    @property
    def deciliters_per_second(self) -> float:
        """
        
        """
        if self.__deciliters_per_second != None:
            return self.__deciliters_per_second
        self.__deciliters_per_second = self.__convert_from_base(VolumeFlowUnits.DeciliterPerSecond)
        return self.__deciliters_per_second

    
    @property
    def kiloliters_per_second(self) -> float:
        """
        
        """
        if self.__kiloliters_per_second != None:
            return self.__kiloliters_per_second
        self.__kiloliters_per_second = self.__convert_from_base(VolumeFlowUnits.KiloliterPerSecond)
        return self.__kiloliters_per_second

    
    @property
    def megaliters_per_second(self) -> float:
        """
        
        """
        if self.__megaliters_per_second != None:
            return self.__megaliters_per_second
        self.__megaliters_per_second = self.__convert_from_base(VolumeFlowUnits.MegaliterPerSecond)
        return self.__megaliters_per_second

    
    @property
    def nanoliters_per_minute(self) -> float:
        """
        
        """
        if self.__nanoliters_per_minute != None:
            return self.__nanoliters_per_minute
        self.__nanoliters_per_minute = self.__convert_from_base(VolumeFlowUnits.NanoliterPerMinute)
        return self.__nanoliters_per_minute

    
    @property
    def microliters_per_minute(self) -> float:
        """
        
        """
        if self.__microliters_per_minute != None:
            return self.__microliters_per_minute
        self.__microliters_per_minute = self.__convert_from_base(VolumeFlowUnits.MicroliterPerMinute)
        return self.__microliters_per_minute

    
    @property
    def milliliters_per_minute(self) -> float:
        """
        
        """
        if self.__milliliters_per_minute != None:
            return self.__milliliters_per_minute
        self.__milliliters_per_minute = self.__convert_from_base(VolumeFlowUnits.MilliliterPerMinute)
        return self.__milliliters_per_minute

    
    @property
    def centiliters_per_minute(self) -> float:
        """
        
        """
        if self.__centiliters_per_minute != None:
            return self.__centiliters_per_minute
        self.__centiliters_per_minute = self.__convert_from_base(VolumeFlowUnits.CentiliterPerMinute)
        return self.__centiliters_per_minute

    
    @property
    def deciliters_per_minute(self) -> float:
        """
        
        """
        if self.__deciliters_per_minute != None:
            return self.__deciliters_per_minute
        self.__deciliters_per_minute = self.__convert_from_base(VolumeFlowUnits.DeciliterPerMinute)
        return self.__deciliters_per_minute

    
    @property
    def kiloliters_per_minute(self) -> float:
        """
        
        """
        if self.__kiloliters_per_minute != None:
            return self.__kiloliters_per_minute
        self.__kiloliters_per_minute = self.__convert_from_base(VolumeFlowUnits.KiloliterPerMinute)
        return self.__kiloliters_per_minute

    
    @property
    def megaliters_per_minute(self) -> float:
        """
        
        """
        if self.__megaliters_per_minute != None:
            return self.__megaliters_per_minute
        self.__megaliters_per_minute = self.__convert_from_base(VolumeFlowUnits.MegaliterPerMinute)
        return self.__megaliters_per_minute

    
    @property
    def nanoliters_per_hour(self) -> float:
        """
        
        """
        if self.__nanoliters_per_hour != None:
            return self.__nanoliters_per_hour
        self.__nanoliters_per_hour = self.__convert_from_base(VolumeFlowUnits.NanoliterPerHour)
        return self.__nanoliters_per_hour

    
    @property
    def microliters_per_hour(self) -> float:
        """
        
        """
        if self.__microliters_per_hour != None:
            return self.__microliters_per_hour
        self.__microliters_per_hour = self.__convert_from_base(VolumeFlowUnits.MicroliterPerHour)
        return self.__microliters_per_hour

    
    @property
    def milliliters_per_hour(self) -> float:
        """
        
        """
        if self.__milliliters_per_hour != None:
            return self.__milliliters_per_hour
        self.__milliliters_per_hour = self.__convert_from_base(VolumeFlowUnits.MilliliterPerHour)
        return self.__milliliters_per_hour

    
    @property
    def centiliters_per_hour(self) -> float:
        """
        
        """
        if self.__centiliters_per_hour != None:
            return self.__centiliters_per_hour
        self.__centiliters_per_hour = self.__convert_from_base(VolumeFlowUnits.CentiliterPerHour)
        return self.__centiliters_per_hour

    
    @property
    def deciliters_per_hour(self) -> float:
        """
        
        """
        if self.__deciliters_per_hour != None:
            return self.__deciliters_per_hour
        self.__deciliters_per_hour = self.__convert_from_base(VolumeFlowUnits.DeciliterPerHour)
        return self.__deciliters_per_hour

    
    @property
    def kiloliters_per_hour(self) -> float:
        """
        
        """
        if self.__kiloliters_per_hour != None:
            return self.__kiloliters_per_hour
        self.__kiloliters_per_hour = self.__convert_from_base(VolumeFlowUnits.KiloliterPerHour)
        return self.__kiloliters_per_hour

    
    @property
    def megaliters_per_hour(self) -> float:
        """
        
        """
        if self.__megaliters_per_hour != None:
            return self.__megaliters_per_hour
        self.__megaliters_per_hour = self.__convert_from_base(VolumeFlowUnits.MegaliterPerHour)
        return self.__megaliters_per_hour

    
    @property
    def nanoliters_per_day(self) -> float:
        """
        
        """
        if self.__nanoliters_per_day != None:
            return self.__nanoliters_per_day
        self.__nanoliters_per_day = self.__convert_from_base(VolumeFlowUnits.NanoliterPerDay)
        return self.__nanoliters_per_day

    
    @property
    def microliters_per_day(self) -> float:
        """
        
        """
        if self.__microliters_per_day != None:
            return self.__microliters_per_day
        self.__microliters_per_day = self.__convert_from_base(VolumeFlowUnits.MicroliterPerDay)
        return self.__microliters_per_day

    
    @property
    def milliliters_per_day(self) -> float:
        """
        
        """
        if self.__milliliters_per_day != None:
            return self.__milliliters_per_day
        self.__milliliters_per_day = self.__convert_from_base(VolumeFlowUnits.MilliliterPerDay)
        return self.__milliliters_per_day

    
    @property
    def centiliters_per_day(self) -> float:
        """
        
        """
        if self.__centiliters_per_day != None:
            return self.__centiliters_per_day
        self.__centiliters_per_day = self.__convert_from_base(VolumeFlowUnits.CentiliterPerDay)
        return self.__centiliters_per_day

    
    @property
    def deciliters_per_day(self) -> float:
        """
        
        """
        if self.__deciliters_per_day != None:
            return self.__deciliters_per_day
        self.__deciliters_per_day = self.__convert_from_base(VolumeFlowUnits.DeciliterPerDay)
        return self.__deciliters_per_day

    
    @property
    def kiloliters_per_day(self) -> float:
        """
        
        """
        if self.__kiloliters_per_day != None:
            return self.__kiloliters_per_day
        self.__kiloliters_per_day = self.__convert_from_base(VolumeFlowUnits.KiloliterPerDay)
        return self.__kiloliters_per_day

    
    @property
    def megaliters_per_day(self) -> float:
        """
        
        """
        if self.__megaliters_per_day != None:
            return self.__megaliters_per_day
        self.__megaliters_per_day = self.__convert_from_base(VolumeFlowUnits.MegaliterPerDay)
        return self.__megaliters_per_day

    
    @property
    def megauk_gallons_per_day(self) -> float:
        """
        
        """
        if self.__megauk_gallons_per_day != None:
            return self.__megauk_gallons_per_day
        self.__megauk_gallons_per_day = self.__convert_from_base(VolumeFlowUnits.MegaukGallonPerDay)
        return self.__megauk_gallons_per_day

    
    @property
    def megauk_gallons_per_second(self) -> float:
        """
        
        """
        if self.__megauk_gallons_per_second != None:
            return self.__megauk_gallons_per_second
        self.__megauk_gallons_per_second = self.__convert_from_base(VolumeFlowUnits.MegaukGallonPerSecond)
        return self.__megauk_gallons_per_second

    
    def to_string(self, unit: VolumeFlowUnits = VolumeFlowUnits.CubicMeterPerSecond) -> string:
        """
        Format the VolumeFlow to string.
        Note! the default format for VolumeFlow is CubicMeterPerSecond.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == VolumeFlowUnits.CubicMeterPerSecond:
            return f"""{self.cubic_meters_per_second} m³/s"""
        
        if unit == VolumeFlowUnits.CubicMeterPerMinute:
            return f"""{self.cubic_meters_per_minute} m³/min"""
        
        if unit == VolumeFlowUnits.CubicMeterPerHour:
            return f"""{self.cubic_meters_per_hour} m³/h"""
        
        if unit == VolumeFlowUnits.CubicMeterPerDay:
            return f"""{self.cubic_meters_per_day} m³/d"""
        
        if unit == VolumeFlowUnits.CubicFootPerSecond:
            return f"""{self.cubic_feet_per_second} ft³/s"""
        
        if unit == VolumeFlowUnits.CubicFootPerMinute:
            return f"""{self.cubic_feet_per_minute} ft³/min"""
        
        if unit == VolumeFlowUnits.CubicFootPerHour:
            return f"""{self.cubic_feet_per_hour} ft³/h"""
        
        if unit == VolumeFlowUnits.CubicYardPerSecond:
            return f"""{self.cubic_yards_per_second} yd³/s"""
        
        if unit == VolumeFlowUnits.CubicYardPerMinute:
            return f"""{self.cubic_yards_per_minute} yd³/min"""
        
        if unit == VolumeFlowUnits.CubicYardPerHour:
            return f"""{self.cubic_yards_per_hour} yd³/h"""
        
        if unit == VolumeFlowUnits.CubicYardPerDay:
            return f"""{self.cubic_yards_per_day} cy/day"""
        
        if unit == VolumeFlowUnits.MillionUsGallonPerDay:
            return f"""{self.million_us_gallons_per_day} MGD"""
        
        if unit == VolumeFlowUnits.UsGallonPerDay:
            return f"""{self.us_gallons_per_day} gpd"""
        
        if unit == VolumeFlowUnits.LiterPerSecond:
            return f"""{self.liters_per_second} L/s"""
        
        if unit == VolumeFlowUnits.LiterPerMinute:
            return f"""{self.liters_per_minute} L/min"""
        
        if unit == VolumeFlowUnits.LiterPerHour:
            return f"""{self.liters_per_hour} L/h"""
        
        if unit == VolumeFlowUnits.LiterPerDay:
            return f"""{self.liters_per_day} l/day"""
        
        if unit == VolumeFlowUnits.UsGallonPerSecond:
            return f"""{self.us_gallons_per_second} gal (U.S.)/s"""
        
        if unit == VolumeFlowUnits.UsGallonPerMinute:
            return f"""{self.us_gallons_per_minute} gal (U.S.)/min"""
        
        if unit == VolumeFlowUnits.UkGallonPerDay:
            return f"""{self.uk_gallons_per_day} gal (U. K.)/d"""
        
        if unit == VolumeFlowUnits.UkGallonPerHour:
            return f"""{self.uk_gallons_per_hour} gal (imp.)/h"""
        
        if unit == VolumeFlowUnits.UkGallonPerMinute:
            return f"""{self.uk_gallons_per_minute} gal (imp.)/min"""
        
        if unit == VolumeFlowUnits.UkGallonPerSecond:
            return f"""{self.uk_gallons_per_second} gal (imp.)/s"""
        
        if unit == VolumeFlowUnits.KilousGallonPerMinute:
            return f"""{self.kilous_gallons_per_minute} kgal (U.S.)/min"""
        
        if unit == VolumeFlowUnits.UsGallonPerHour:
            return f"""{self.us_gallons_per_hour} gal (U.S.)/h"""
        
        if unit == VolumeFlowUnits.CubicDecimeterPerMinute:
            return f"""{self.cubic_decimeters_per_minute} dm³/min"""
        
        if unit == VolumeFlowUnits.OilBarrelPerDay:
            return f"""{self.oil_barrels_per_day} bbl/d"""
        
        if unit == VolumeFlowUnits.OilBarrelPerMinute:
            return f"""{self.oil_barrels_per_minute} bbl/min"""
        
        if unit == VolumeFlowUnits.OilBarrelPerHour:
            return f"""{self.oil_barrels_per_hour} bbl/hr"""
        
        if unit == VolumeFlowUnits.OilBarrelPerSecond:
            return f"""{self.oil_barrels_per_second} bbl/s"""
        
        if unit == VolumeFlowUnits.CubicMillimeterPerSecond:
            return f"""{self.cubic_millimeters_per_second} mm³/s"""
        
        if unit == VolumeFlowUnits.AcreFootPerSecond:
            return f"""{self.acre_feet_per_second} af/s"""
        
        if unit == VolumeFlowUnits.AcreFootPerMinute:
            return f"""{self.acre_feet_per_minute} af/m"""
        
        if unit == VolumeFlowUnits.AcreFootPerHour:
            return f"""{self.acre_feet_per_hour} af/h"""
        
        if unit == VolumeFlowUnits.AcreFootPerDay:
            return f"""{self.acre_feet_per_day} af/d"""
        
        if unit == VolumeFlowUnits.CubicCentimeterPerMinute:
            return f"""{self.cubic_centimeters_per_minute} cm³/min"""
        
        if unit == VolumeFlowUnits.MegausGallonPerDay:
            return f"""{self.megaus_gallons_per_day} """
        
        if unit == VolumeFlowUnits.NanoliterPerSecond:
            return f"""{self.nanoliters_per_second} """
        
        if unit == VolumeFlowUnits.MicroliterPerSecond:
            return f"""{self.microliters_per_second} """
        
        if unit == VolumeFlowUnits.MilliliterPerSecond:
            return f"""{self.milliliters_per_second} """
        
        if unit == VolumeFlowUnits.CentiliterPerSecond:
            return f"""{self.centiliters_per_second} """
        
        if unit == VolumeFlowUnits.DeciliterPerSecond:
            return f"""{self.deciliters_per_second} """
        
        if unit == VolumeFlowUnits.KiloliterPerSecond:
            return f"""{self.kiloliters_per_second} """
        
        if unit == VolumeFlowUnits.MegaliterPerSecond:
            return f"""{self.megaliters_per_second} """
        
        if unit == VolumeFlowUnits.NanoliterPerMinute:
            return f"""{self.nanoliters_per_minute} """
        
        if unit == VolumeFlowUnits.MicroliterPerMinute:
            return f"""{self.microliters_per_minute} """
        
        if unit == VolumeFlowUnits.MilliliterPerMinute:
            return f"""{self.milliliters_per_minute} """
        
        if unit == VolumeFlowUnits.CentiliterPerMinute:
            return f"""{self.centiliters_per_minute} """
        
        if unit == VolumeFlowUnits.DeciliterPerMinute:
            return f"""{self.deciliters_per_minute} """
        
        if unit == VolumeFlowUnits.KiloliterPerMinute:
            return f"""{self.kiloliters_per_minute} """
        
        if unit == VolumeFlowUnits.MegaliterPerMinute:
            return f"""{self.megaliters_per_minute} """
        
        if unit == VolumeFlowUnits.NanoliterPerHour:
            return f"""{self.nanoliters_per_hour} """
        
        if unit == VolumeFlowUnits.MicroliterPerHour:
            return f"""{self.microliters_per_hour} """
        
        if unit == VolumeFlowUnits.MilliliterPerHour:
            return f"""{self.milliliters_per_hour} """
        
        if unit == VolumeFlowUnits.CentiliterPerHour:
            return f"""{self.centiliters_per_hour} """
        
        if unit == VolumeFlowUnits.DeciliterPerHour:
            return f"""{self.deciliters_per_hour} """
        
        if unit == VolumeFlowUnits.KiloliterPerHour:
            return f"""{self.kiloliters_per_hour} """
        
        if unit == VolumeFlowUnits.MegaliterPerHour:
            return f"""{self.megaliters_per_hour} """
        
        if unit == VolumeFlowUnits.NanoliterPerDay:
            return f"""{self.nanoliters_per_day} """
        
        if unit == VolumeFlowUnits.MicroliterPerDay:
            return f"""{self.microliters_per_day} """
        
        if unit == VolumeFlowUnits.MilliliterPerDay:
            return f"""{self.milliliters_per_day} """
        
        if unit == VolumeFlowUnits.CentiliterPerDay:
            return f"""{self.centiliters_per_day} """
        
        if unit == VolumeFlowUnits.DeciliterPerDay:
            return f"""{self.deciliters_per_day} """
        
        if unit == VolumeFlowUnits.KiloliterPerDay:
            return f"""{self.kiloliters_per_day} """
        
        if unit == VolumeFlowUnits.MegaliterPerDay:
            return f"""{self.megaliters_per_day} """
        
        if unit == VolumeFlowUnits.MegaukGallonPerDay:
            return f"""{self.megauk_gallons_per_day} """
        
        if unit == VolumeFlowUnits.MegaukGallonPerSecond:
            return f"""{self.megauk_gallons_per_second} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: VolumeFlowUnits = VolumeFlowUnits.CubicMeterPerSecond) -> string:
        """
        Get VolumeFlow unit abbreviation.
        Note! the default abbreviation for VolumeFlow is CubicMeterPerSecond.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == VolumeFlowUnits.CubicMeterPerSecond:
            return """m³/s"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicMeterPerMinute:
            return """m³/min"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicMeterPerHour:
            return """m³/h"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicMeterPerDay:
            return """m³/d"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicFootPerSecond:
            return """ft³/s"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicFootPerMinute:
            return """ft³/min"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicFootPerHour:
            return """ft³/h"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicYardPerSecond:
            return """yd³/s"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicYardPerMinute:
            return """yd³/min"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicYardPerHour:
            return """yd³/h"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicYardPerDay:
            return """cy/day"""
        
        if unit_abbreviation == VolumeFlowUnits.MillionUsGallonPerDay:
            return """MGD"""
        
        if unit_abbreviation == VolumeFlowUnits.UsGallonPerDay:
            return """gpd"""
        
        if unit_abbreviation == VolumeFlowUnits.LiterPerSecond:
            return """L/s"""
        
        if unit_abbreviation == VolumeFlowUnits.LiterPerMinute:
            return """L/min"""
        
        if unit_abbreviation == VolumeFlowUnits.LiterPerHour:
            return """L/h"""
        
        if unit_abbreviation == VolumeFlowUnits.LiterPerDay:
            return """l/day"""
        
        if unit_abbreviation == VolumeFlowUnits.UsGallonPerSecond:
            return """gal (U.S.)/s"""
        
        if unit_abbreviation == VolumeFlowUnits.UsGallonPerMinute:
            return """gal (U.S.)/min"""
        
        if unit_abbreviation == VolumeFlowUnits.UkGallonPerDay:
            return """gal (U. K.)/d"""
        
        if unit_abbreviation == VolumeFlowUnits.UkGallonPerHour:
            return """gal (imp.)/h"""
        
        if unit_abbreviation == VolumeFlowUnits.UkGallonPerMinute:
            return """gal (imp.)/min"""
        
        if unit_abbreviation == VolumeFlowUnits.UkGallonPerSecond:
            return """gal (imp.)/s"""
        
        if unit_abbreviation == VolumeFlowUnits.KilousGallonPerMinute:
            return """kgal (U.S.)/min"""
        
        if unit_abbreviation == VolumeFlowUnits.UsGallonPerHour:
            return """gal (U.S.)/h"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicDecimeterPerMinute:
            return """dm³/min"""
        
        if unit_abbreviation == VolumeFlowUnits.OilBarrelPerDay:
            return """bbl/d"""
        
        if unit_abbreviation == VolumeFlowUnits.OilBarrelPerMinute:
            return """bbl/min"""
        
        if unit_abbreviation == VolumeFlowUnits.OilBarrelPerHour:
            return """bbl/hr"""
        
        if unit_abbreviation == VolumeFlowUnits.OilBarrelPerSecond:
            return """bbl/s"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicMillimeterPerSecond:
            return """mm³/s"""
        
        if unit_abbreviation == VolumeFlowUnits.AcreFootPerSecond:
            return """af/s"""
        
        if unit_abbreviation == VolumeFlowUnits.AcreFootPerMinute:
            return """af/m"""
        
        if unit_abbreviation == VolumeFlowUnits.AcreFootPerHour:
            return """af/h"""
        
        if unit_abbreviation == VolumeFlowUnits.AcreFootPerDay:
            return """af/d"""
        
        if unit_abbreviation == VolumeFlowUnits.CubicCentimeterPerMinute:
            return """cm³/min"""
        
        if unit_abbreviation == VolumeFlowUnits.MegausGallonPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.NanoliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MicroliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MilliliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.CentiliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.DeciliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.KiloliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MegaliterPerSecond:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.NanoliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MicroliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MilliliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.CentiliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.DeciliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.KiloliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MegaliterPerMinute:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.NanoliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MicroliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MilliliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.CentiliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.DeciliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.KiloliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MegaliterPerHour:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.NanoliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MicroliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MilliliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.CentiliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.DeciliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.KiloliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MegaliterPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MegaukGallonPerDay:
            return """"""
        
        if unit_abbreviation == VolumeFlowUnits.MegaukGallonPerSecond:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for +: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return VolumeFlow(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for *: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return VolumeFlow(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for -: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return VolumeFlow(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for /: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return VolumeFlow(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for %: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return VolumeFlow(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for **: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return VolumeFlow(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for ==: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for <: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for >: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for <=: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, VolumeFlow):
            raise TypeError("unsupported operand type(s) for >=: 'VolumeFlow' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ElectricPotentialUnits(Enum):
        """
            ElectricPotentialUnits enumeration
        """
        
        Volt = 'volt'
        """
            
        """
        
        Nanovolt = 'nanovolt'
        """
            
        """
        
        Microvolt = 'microvolt'
        """
            
        """
        
        Millivolt = 'millivolt'
        """
            
        """
        
        Kilovolt = 'kilovolt'
        """
            
        """
        
        Megavolt = 'megavolt'
        """
            
        """
        

class ElectricPotential:
    """
    In classical electromagnetism, the electric potential (a scalar quantity denoted by Φ, ΦE or V and also called the electric field potential or the electrostatic potential) at a point is the amount of electric potential energy that a unitary point charge would have when located at that point.

    Args:
        value (float): The value.
        from_unit (ElectricPotentialUnits): The ElectricPotential unit to create from, The default unit is Volt
    """
    def __init__(self, value: float, from_unit: ElectricPotentialUnits = ElectricPotentialUnits.Volt):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__volts = None
        
        self.__nanovolts = None
        
        self.__microvolts = None
        
        self.__millivolts = None
        
        self.__kilovolts = None
        
        self.__megavolts = None
        

    def __convert_from_base(self, from_unit: ElectricPotentialUnits) -> float:
        value = self.__value
        
        if from_unit == ElectricPotentialUnits.Volt:
            return (value)
        
        if from_unit == ElectricPotentialUnits.Nanovolt:
            return ((value) / 1e-09)
        
        if from_unit == ElectricPotentialUnits.Microvolt:
            return ((value) / 1e-06)
        
        if from_unit == ElectricPotentialUnits.Millivolt:
            return ((value) / 0.001)
        
        if from_unit == ElectricPotentialUnits.Kilovolt:
            return ((value) / 1000.0)
        
        if from_unit == ElectricPotentialUnits.Megavolt:
            return ((value) / 1000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ElectricPotentialUnits) -> float:
        
        if to_unit == ElectricPotentialUnits.Volt:
            return (value)
        
        if to_unit == ElectricPotentialUnits.Nanovolt:
            return ((value) * 1e-09)
        
        if to_unit == ElectricPotentialUnits.Microvolt:
            return ((value) * 1e-06)
        
        if to_unit == ElectricPotentialUnits.Millivolt:
            return ((value) * 0.001)
        
        if to_unit == ElectricPotentialUnits.Kilovolt:
            return ((value) * 1000.0)
        
        if to_unit == ElectricPotentialUnits.Megavolt:
            return ((value) * 1000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_volts(volts: float):
        """
        Create a new instance of ElectricPotential from a value in volts.

        

        :param meters: The ElectricPotential value in volts.
        :type volts: float
        :return: A new instance of ElectricPotential.
        :rtype: ElectricPotential
        """
        return ElectricPotential(volts, ElectricPotentialUnits.Volt)

    
    @staticmethod
    def from_nanovolts(nanovolts: float):
        """
        Create a new instance of ElectricPotential from a value in nanovolts.

        

        :param meters: The ElectricPotential value in nanovolts.
        :type nanovolts: float
        :return: A new instance of ElectricPotential.
        :rtype: ElectricPotential
        """
        return ElectricPotential(nanovolts, ElectricPotentialUnits.Nanovolt)

    
    @staticmethod
    def from_microvolts(microvolts: float):
        """
        Create a new instance of ElectricPotential from a value in microvolts.

        

        :param meters: The ElectricPotential value in microvolts.
        :type microvolts: float
        :return: A new instance of ElectricPotential.
        :rtype: ElectricPotential
        """
        return ElectricPotential(microvolts, ElectricPotentialUnits.Microvolt)

    
    @staticmethod
    def from_millivolts(millivolts: float):
        """
        Create a new instance of ElectricPotential from a value in millivolts.

        

        :param meters: The ElectricPotential value in millivolts.
        :type millivolts: float
        :return: A new instance of ElectricPotential.
        :rtype: ElectricPotential
        """
        return ElectricPotential(millivolts, ElectricPotentialUnits.Millivolt)

    
    @staticmethod
    def from_kilovolts(kilovolts: float):
        """
        Create a new instance of ElectricPotential from a value in kilovolts.

        

        :param meters: The ElectricPotential value in kilovolts.
        :type kilovolts: float
        :return: A new instance of ElectricPotential.
        :rtype: ElectricPotential
        """
        return ElectricPotential(kilovolts, ElectricPotentialUnits.Kilovolt)

    
    @staticmethod
    def from_megavolts(megavolts: float):
        """
        Create a new instance of ElectricPotential from a value in megavolts.

        

        :param meters: The ElectricPotential value in megavolts.
        :type megavolts: float
        :return: A new instance of ElectricPotential.
        :rtype: ElectricPotential
        """
        return ElectricPotential(megavolts, ElectricPotentialUnits.Megavolt)

    
    @property
    def volts(self) -> float:
        """
        
        """
        if self.__volts != None:
            return self.__volts
        self.__volts = self.__convert_from_base(ElectricPotentialUnits.Volt)
        return self.__volts

    
    @property
    def nanovolts(self) -> float:
        """
        
        """
        if self.__nanovolts != None:
            return self.__nanovolts
        self.__nanovolts = self.__convert_from_base(ElectricPotentialUnits.Nanovolt)
        return self.__nanovolts

    
    @property
    def microvolts(self) -> float:
        """
        
        """
        if self.__microvolts != None:
            return self.__microvolts
        self.__microvolts = self.__convert_from_base(ElectricPotentialUnits.Microvolt)
        return self.__microvolts

    
    @property
    def millivolts(self) -> float:
        """
        
        """
        if self.__millivolts != None:
            return self.__millivolts
        self.__millivolts = self.__convert_from_base(ElectricPotentialUnits.Millivolt)
        return self.__millivolts

    
    @property
    def kilovolts(self) -> float:
        """
        
        """
        if self.__kilovolts != None:
            return self.__kilovolts
        self.__kilovolts = self.__convert_from_base(ElectricPotentialUnits.Kilovolt)
        return self.__kilovolts

    
    @property
    def megavolts(self) -> float:
        """
        
        """
        if self.__megavolts != None:
            return self.__megavolts
        self.__megavolts = self.__convert_from_base(ElectricPotentialUnits.Megavolt)
        return self.__megavolts

    
    def to_string(self, unit: ElectricPotentialUnits = ElectricPotentialUnits.Volt) -> string:
        """
        Format the ElectricPotential to string.
        Note! the default format for ElectricPotential is Volt.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ElectricPotentialUnits.Volt:
            return f"""{self.volts} V"""
        
        if unit == ElectricPotentialUnits.Nanovolt:
            return f"""{self.nanovolts} """
        
        if unit == ElectricPotentialUnits.Microvolt:
            return f"""{self.microvolts} """
        
        if unit == ElectricPotentialUnits.Millivolt:
            return f"""{self.millivolts} """
        
        if unit == ElectricPotentialUnits.Kilovolt:
            return f"""{self.kilovolts} """
        
        if unit == ElectricPotentialUnits.Megavolt:
            return f"""{self.megavolts} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ElectricPotentialUnits = ElectricPotentialUnits.Volt) -> string:
        """
        Get ElectricPotential unit abbreviation.
        Note! the default abbreviation for ElectricPotential is Volt.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ElectricPotentialUnits.Volt:
            return """V"""
        
        if unit_abbreviation == ElectricPotentialUnits.Nanovolt:
            return """"""
        
        if unit_abbreviation == ElectricPotentialUnits.Microvolt:
            return """"""
        
        if unit_abbreviation == ElectricPotentialUnits.Millivolt:
            return """"""
        
        if unit_abbreviation == ElectricPotentialUnits.Kilovolt:
            return """"""
        
        if unit_abbreviation == ElectricPotentialUnits.Megavolt:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for +: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return ElectricPotential(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for *: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return ElectricPotential(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for -: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return ElectricPotential(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for /: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return ElectricPotential(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for %: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return ElectricPotential(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for **: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return ElectricPotential(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for ==: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for <: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for >: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for <=: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ElectricPotential):
            raise TypeError("unsupported operand type(s) for >=: 'ElectricPotential' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class ApparentPowerUnits(Enum):
        """
            ApparentPowerUnits enumeration
        """
        
        Voltampere = 'voltampere'
        """
            
        """
        
        Microvoltampere = 'microvoltampere'
        """
            
        """
        
        Millivoltampere = 'millivoltampere'
        """
            
        """
        
        Kilovoltampere = 'kilovoltampere'
        """
            
        """
        
        Megavoltampere = 'megavoltampere'
        """
            
        """
        
        Gigavoltampere = 'gigavoltampere'
        """
            
        """
        

class ApparentPower:
    """
    Power engineers measure apparent power as the magnitude of the vector sum of active and reactive power. Apparent power is the product of the root-mean-square of voltage and current.

    Args:
        value (float): The value.
        from_unit (ApparentPowerUnits): The ApparentPower unit to create from, The default unit is Voltampere
    """
    def __init__(self, value: float, from_unit: ApparentPowerUnits = ApparentPowerUnits.Voltampere):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__voltamperes = None
        
        self.__microvoltamperes = None
        
        self.__millivoltamperes = None
        
        self.__kilovoltamperes = None
        
        self.__megavoltamperes = None
        
        self.__gigavoltamperes = None
        

    def __convert_from_base(self, from_unit: ApparentPowerUnits) -> float:
        value = self.__value
        
        if from_unit == ApparentPowerUnits.Voltampere:
            return (value)
        
        if from_unit == ApparentPowerUnits.Microvoltampere:
            return ((value) / 1e-06)
        
        if from_unit == ApparentPowerUnits.Millivoltampere:
            return ((value) / 0.001)
        
        if from_unit == ApparentPowerUnits.Kilovoltampere:
            return ((value) / 1000.0)
        
        if from_unit == ApparentPowerUnits.Megavoltampere:
            return ((value) / 1000000.0)
        
        if from_unit == ApparentPowerUnits.Gigavoltampere:
            return ((value) / 1000000000.0)
        
        return None


    def __convert_to_base(self, value: float, to_unit: ApparentPowerUnits) -> float:
        
        if to_unit == ApparentPowerUnits.Voltampere:
            return (value)
        
        if to_unit == ApparentPowerUnits.Microvoltampere:
            return ((value) * 1e-06)
        
        if to_unit == ApparentPowerUnits.Millivoltampere:
            return ((value) * 0.001)
        
        if to_unit == ApparentPowerUnits.Kilovoltampere:
            return ((value) * 1000.0)
        
        if to_unit == ApparentPowerUnits.Megavoltampere:
            return ((value) * 1000000.0)
        
        if to_unit == ApparentPowerUnits.Gigavoltampere:
            return ((value) * 1000000000.0)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_voltamperes(voltamperes: float):
        """
        Create a new instance of ApparentPower from a value in voltamperes.

        

        :param meters: The ApparentPower value in voltamperes.
        :type voltamperes: float
        :return: A new instance of ApparentPower.
        :rtype: ApparentPower
        """
        return ApparentPower(voltamperes, ApparentPowerUnits.Voltampere)

    
    @staticmethod
    def from_microvoltamperes(microvoltamperes: float):
        """
        Create a new instance of ApparentPower from a value in microvoltamperes.

        

        :param meters: The ApparentPower value in microvoltamperes.
        :type microvoltamperes: float
        :return: A new instance of ApparentPower.
        :rtype: ApparentPower
        """
        return ApparentPower(microvoltamperes, ApparentPowerUnits.Microvoltampere)

    
    @staticmethod
    def from_millivoltamperes(millivoltamperes: float):
        """
        Create a new instance of ApparentPower from a value in millivoltamperes.

        

        :param meters: The ApparentPower value in millivoltamperes.
        :type millivoltamperes: float
        :return: A new instance of ApparentPower.
        :rtype: ApparentPower
        """
        return ApparentPower(millivoltamperes, ApparentPowerUnits.Millivoltampere)

    
    @staticmethod
    def from_kilovoltamperes(kilovoltamperes: float):
        """
        Create a new instance of ApparentPower from a value in kilovoltamperes.

        

        :param meters: The ApparentPower value in kilovoltamperes.
        :type kilovoltamperes: float
        :return: A new instance of ApparentPower.
        :rtype: ApparentPower
        """
        return ApparentPower(kilovoltamperes, ApparentPowerUnits.Kilovoltampere)

    
    @staticmethod
    def from_megavoltamperes(megavoltamperes: float):
        """
        Create a new instance of ApparentPower from a value in megavoltamperes.

        

        :param meters: The ApparentPower value in megavoltamperes.
        :type megavoltamperes: float
        :return: A new instance of ApparentPower.
        :rtype: ApparentPower
        """
        return ApparentPower(megavoltamperes, ApparentPowerUnits.Megavoltampere)

    
    @staticmethod
    def from_gigavoltamperes(gigavoltamperes: float):
        """
        Create a new instance of ApparentPower from a value in gigavoltamperes.

        

        :param meters: The ApparentPower value in gigavoltamperes.
        :type gigavoltamperes: float
        :return: A new instance of ApparentPower.
        :rtype: ApparentPower
        """
        return ApparentPower(gigavoltamperes, ApparentPowerUnits.Gigavoltampere)

    
    @property
    def voltamperes(self) -> float:
        """
        
        """
        if self.__voltamperes != None:
            return self.__voltamperes
        self.__voltamperes = self.__convert_from_base(ApparentPowerUnits.Voltampere)
        return self.__voltamperes

    
    @property
    def microvoltamperes(self) -> float:
        """
        
        """
        if self.__microvoltamperes != None:
            return self.__microvoltamperes
        self.__microvoltamperes = self.__convert_from_base(ApparentPowerUnits.Microvoltampere)
        return self.__microvoltamperes

    
    @property
    def millivoltamperes(self) -> float:
        """
        
        """
        if self.__millivoltamperes != None:
            return self.__millivoltamperes
        self.__millivoltamperes = self.__convert_from_base(ApparentPowerUnits.Millivoltampere)
        return self.__millivoltamperes

    
    @property
    def kilovoltamperes(self) -> float:
        """
        
        """
        if self.__kilovoltamperes != None:
            return self.__kilovoltamperes
        self.__kilovoltamperes = self.__convert_from_base(ApparentPowerUnits.Kilovoltampere)
        return self.__kilovoltamperes

    
    @property
    def megavoltamperes(self) -> float:
        """
        
        """
        if self.__megavoltamperes != None:
            return self.__megavoltamperes
        self.__megavoltamperes = self.__convert_from_base(ApparentPowerUnits.Megavoltampere)
        return self.__megavoltamperes

    
    @property
    def gigavoltamperes(self) -> float:
        """
        
        """
        if self.__gigavoltamperes != None:
            return self.__gigavoltamperes
        self.__gigavoltamperes = self.__convert_from_base(ApparentPowerUnits.Gigavoltampere)
        return self.__gigavoltamperes

    
    def to_string(self, unit: ApparentPowerUnits = ApparentPowerUnits.Voltampere) -> string:
        """
        Format the ApparentPower to string.
        Note! the default format for ApparentPower is Voltampere.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == ApparentPowerUnits.Voltampere:
            return f"""{self.voltamperes} VA"""
        
        if unit == ApparentPowerUnits.Microvoltampere:
            return f"""{self.microvoltamperes} """
        
        if unit == ApparentPowerUnits.Millivoltampere:
            return f"""{self.millivoltamperes} """
        
        if unit == ApparentPowerUnits.Kilovoltampere:
            return f"""{self.kilovoltamperes} """
        
        if unit == ApparentPowerUnits.Megavoltampere:
            return f"""{self.megavoltamperes} """
        
        if unit == ApparentPowerUnits.Gigavoltampere:
            return f"""{self.gigavoltamperes} """
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: ApparentPowerUnits = ApparentPowerUnits.Voltampere) -> string:
        """
        Get ApparentPower unit abbreviation.
        Note! the default abbreviation for ApparentPower is Voltampere.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == ApparentPowerUnits.Voltampere:
            return """VA"""
        
        if unit_abbreviation == ApparentPowerUnits.Microvoltampere:
            return """"""
        
        if unit_abbreviation == ApparentPowerUnits.Millivoltampere:
            return """"""
        
        if unit_abbreviation == ApparentPowerUnits.Kilovoltampere:
            return """"""
        
        if unit_abbreviation == ApparentPowerUnits.Megavoltampere:
            return """"""
        
        if unit_abbreviation == ApparentPowerUnits.Gigavoltampere:
            return """"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for +: 'ApparentPower' and '{}'".format(type(other).__name__))
        return ApparentPower(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for *: 'ApparentPower' and '{}'".format(type(other).__name__))
        return ApparentPower(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for -: 'ApparentPower' and '{}'".format(type(other).__name__))
        return ApparentPower(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for /: 'ApparentPower' and '{}'".format(type(other).__name__))
        return ApparentPower(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for %: 'ApparentPower' and '{}'".format(type(other).__name__))
        return ApparentPower(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for **: 'ApparentPower' and '{}'".format(type(other).__name__))
        return ApparentPower(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for ==: 'ApparentPower' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for <: 'ApparentPower' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for >: 'ApparentPower' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for <=: 'ApparentPower' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, ApparentPower):
            raise TypeError("unsupported operand type(s) for >=: 'ApparentPower' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value


from enum import Enum
import math
import string


class LuminousIntensityUnits(Enum):
        """
            LuminousIntensityUnits enumeration
        """
        
        Candela = 'candela'
        """
            
        """
        

class LuminousIntensity:
    """
    In photometry, luminous intensity is a measure of the wavelength-weighted power emitted by a light source in a particular direction per unit solid angle, based on the luminosity function, a standardized model of the sensitivity of the human eye.

    Args:
        value (float): The value.
        from_unit (LuminousIntensityUnits): The LuminousIntensity unit to create from, The default unit is Candela
    """
    def __init__(self, value: float, from_unit: LuminousIntensityUnits = LuminousIntensityUnits.Candela):
        if math.isnan(value):
            raise ValueError('Invalid unit: value is NaN')
        self.__value = self.__convert_to_base(value, from_unit)
        
        self.__candela = None
        

    def __convert_from_base(self, from_unit: LuminousIntensityUnits) -> float:
        value = self.__value
        
        if from_unit == LuminousIntensityUnits.Candela:
            return (value)
        
        return None


    def __convert_to_base(self, value: float, to_unit: LuminousIntensityUnits) -> float:
        
        if to_unit == LuminousIntensityUnits.Candela:
            return (value)
        
        return None


    @property
    def base_value(self) -> float:
        return self.__value

    
    @staticmethod
    def from_candela(candela: float):
        """
        Create a new instance of LuminousIntensity from a value in candela.

        

        :param meters: The LuminousIntensity value in candela.
        :type candela: float
        :return: A new instance of LuminousIntensity.
        :rtype: LuminousIntensity
        """
        return LuminousIntensity(candela, LuminousIntensityUnits.Candela)

    
    @property
    def candela(self) -> float:
        """
        
        """
        if self.__candela != None:
            return self.__candela
        self.__candela = self.__convert_from_base(LuminousIntensityUnits.Candela)
        return self.__candela

    
    def to_string(self, unit: LuminousIntensityUnits = LuminousIntensityUnits.Candela) -> string:
        """
        Format the LuminousIntensity to string.
        Note! the default format for LuminousIntensity is Candela.
        To specify the unit format set the 'unit' parameter.
        """
        
        if unit == LuminousIntensityUnits.Candela:
            return f"""{self.candela} cd"""
        
        return f'{self.__value}'


    def get_unit_abbreviation(self, unit_abbreviation: LuminousIntensityUnits = LuminousIntensityUnits.Candela) -> string:
        """
        Get LuminousIntensity unit abbreviation.
        Note! the default abbreviation for LuminousIntensity is Candela.
        To specify the unit abbreviation set the 'unit_abbreviation' parameter.
        """
        
        if unit_abbreviation == LuminousIntensityUnits.Candela:
            return """cd"""
        

    def __str__(self):
        return self.to_string()


    def __add__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for +: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return LuminousIntensity(self.__value + other.__value)


    def __mul__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for *: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return LuminousIntensity(self.__value * other.__value)


    def __sub__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for -: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return LuminousIntensity(self.__value - other.__value)


    def __truediv__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for /: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return LuminousIntensity(self.__value / other.__value)


    def __mod__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for %: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return LuminousIntensity(self.__value % other.__value)


    def __pow__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for **: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return LuminousIntensity(self.__value ** other.__value)


    def __eq__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for ==: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return self.__value == other.__value


    def __lt__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for <: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return self.__value < other.__value


    def __gt__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for >: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return self.__value > other.__value


    def __le__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for <=: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return self.__value <= other.__value


    def __ge__(self, other):
        if not isinstance(other, LuminousIntensity):
            raise TypeError("unsupported operand type(s) for >=: 'LuminousIntensity' and '{}'".format(type(other).__name__))
        return self.__value >= other.__value